diff lisp/vc-git.el @ 95020:4da572dc4992

Snapshot primitives globally renamed to refer to tags, documentation updated.
author Eric S. Raymond <esr@snark.thyrsus.com>
date Thu, 15 May 2008 17:38:50 +0000
parents 5e64dca662f0
children 09da7727f35f
line wrap: on
line diff
--- a/lisp/vc-git.el	Thu May 15 15:02:57 2008 +0000
+++ b/lisp/vc-git.el	Thu May 15 17:38:50 2008 +0000
@@ -43,37 +43,39 @@
 ;; beginning of vc.el. The current status is:
 ;; ("??" means: "figure out what to do about it")
 ;;
-;; FUNCTION NAME                                   STATUS
+;; FUNCTION NAME                        STATUS
 ;; BACKEND PROPERTIES
-;; * revision-granularity                          OK
+;; * revision-granularity                      OK
 ;; STATE-QUERYING FUNCTIONS
-;; * registered (file)				   OK
+;; * registered (file)			   OK
 ;; * state (file)				   OK
 ;; - state-heuristic (file)			   NOT NEEDED
-;; * working-revision (file)			   OK
-;; - latest-on-branch-p (file)			   NOT NEEDED
-;; * checkout-model (files)			   OK
+;; * working-revision (file)		   OK
+;; - latest-on-branch-p (file)		   NOT NEEDED
+;; * checkout-model (files)		   OK
 ;; - workfile-unchanged-p (file)		   OK
 ;; - mode-line-string (file)			   OK
-;; - prettify-state-info (file)			   OK
+;; - prettify-state-info (file)		   OK
 ;; STATE-CHANGING FUNCTIONS
-;; * create-repo ()				   OK
-;; * register (files &optional rev comment)	   OK
+;; * create-repo ()			   OK
+;; * register (files &optional rev comment)    OK
 ;; - init-revision (file)			   NOT NEEDED
 ;; - responsible-p (file)			   OK
 ;; - could-register (file)			   NOT NEEDED, DEFAULT IS GOOD
 ;; - receive-file (file rev)			   NOT NEEDED
-;; - unregister (file)				   OK
+;; - unregister (file)			   OK
 ;; * checkin (files rev comment)		   OK
 ;; * find-revision (file rev buffer)		   OK
 ;; * checkout (file &optional editable rev)	   OK
 ;; * revert (file &optional contents-done)	   OK
-;; - rollback (files)				   COULD BE SUPPORTED
-;; - merge (file rev1 rev2)			   It would be possible to merge changes into
-;;                                                 a single file, but when committing they
-;;                                                 wouldn't be identified as a merge by git,
-;;                                                 so it's probably not a good idea.
-;; - merge-news (file)				   see `merge'
+;; - rollback (files)			   COULD BE SUPPORTED
+;; - merge (file rev1 rev2)                   It would be possible to merge
+;;                                          changes into a single file, but when
+;;                                          committing they wouldn't
+;;                                          be identified as a merge
+;;                                          by git, so it's probably
+;;                                          not a good idea.
+;; - merge-news (file)			   see `merge'
 ;; - steal-lock (file &optional revision)	   NOT NEEDED
 ;; HISTORY FUNCTIONS
 ;; * print-log (files &optional buffer)		   OK
@@ -81,27 +83,26 @@
 ;; - show-log-entry (revision)			   OK
 ;; - comment-history (file)			   ??
 ;; - update-changelog (files)			   COULD BE SUPPORTED
-;; * diff (file &optional rev1 rev2 buffer)	   OK
+;; * diff (file &optional rev1 rev2 buffer)	           OK
 ;; - revision-completion-table (files)		   OK
 ;; - annotate-command (file buf &optional rev)	   OK
 ;; - annotate-time ()				   OK
 ;; - annotate-current-time ()			   NOT NEEDED
 ;; - annotate-extract-revision-at-line ()	   OK
 ;; SNAPSHOT SYSTEM
 ;; - create-snapshot (dir name branchp)		   OK
 ;; - assign-name (file name)			   NOT NEEDED
 ;; - retrieve-snapshot (dir name update)	   OK, needs to update buffers
 ;; MISCELLANEOUS
-;; - make-version-backups-p (file)		   NOT NEEDED
-;; - repository-hostname (dirname)		   NOT NEEDED
+;; - make-version-backups-p (file)	   NOT NEEDED
+;; - repository-hostname (dirname)	   NOT NEEDED
 ;; - previous-revision (file rev)		   OK
-;; - next-revision (file rev)			   OK
-;; - check-headers ()				   COULD BE SUPPORTED
-;; - clear-headers ()				   NOT NEEDED
-;; - delete-file (file)				   OK
-;; - rename-file (old new)			   OK
-;; - find-file-hook ()				   NOT NEEDED
-;; - find-file-not-found-hook ()                   NOT NEEDED
+;; - next-revision (file rev)		   OK
+;; - check-headers ()			   COULD BE SUPPORTED
+;; - clear-headers ()			   NOT NEEDED
+;; - delete-file (file)			   OK
+;; - rename-file (old new)		   OK
+;; - find-file-hook ()			   NOT NEEDED
+;; - find-file-not-found-hook ()                NOT NEEDED
 
 (eval-when-compile
   (require 'cl)
@@ -554,16 +555,16 @@
     (and (looking-at "[0-9a-f^][0-9a-f]+")
          (buffer-substring-no-properties (match-beginning 0) (match-end 0)))))
 
-;;; SNAPSHOT SYSTEM
+;;; TAG SYSTEM
 
-(defun vc-git-create-snapshot (dir name branchp)
+(defun vc-git-create-tag (dir name branchp)
   (let ((default-directory dir))
     (and (vc-git-command nil 0 nil "update-index" "--refresh")
          (if branchp
              (vc-git-command nil 0 nil "checkout" "-b" name)
            (vc-git-command nil 0 nil "tag" name)))))
 
-(defun vc-git-retrieve-snapshot (dir name update)
+(defun vc-git-retrieve-tag (dir name update)
   (let ((default-directory dir))
     (vc-git-command nil 0 nil "checkout" name)
     ;; FIXME: update buffers if `update' is true
@@ -81,27 +83,26 @@
 ;; - annotate-time ()				   OK
 ;; - annotate-current-time ()			   NOT NEEDED
-;; - annotate-extract-revision-at-line ()	   OK
-;; SNAPSHOT SYSTEM
-;; - create-snapshot (dir name branchp)		   OK
-;; - assign-name (file name)			   NOT NEEDED
-;; - retrieve-snapshot (dir name update)	   OK, needs to update buffers
+;; - annotate-extract-revision-at-line ()	           OK
+;; TAG SYSTEM
+;; - create-tag (dir name branchp)	   OK
+;; - retrieve-tag (dir name update)	   OK, needs to update buffers
 ;; MISCELLANEOUS